@@ -5,11 +5,13 @@
 # All Rights Reserved - See License
 #
 
+use v5.14;
+use strict;
+use warnings;
+
 package Dist::Zilla::PluginBundle::Author::JMASLAK;
 # ABSTRACT: JMASLAK's Plugin Bundle
-$Dist::Zilla::PluginBundle::Author::JMASLAK::VERSION = '0.002';
-use v5.10;
-
+$Dist::Zilla::PluginBundle::Author::JMASLAK::VERSION = '0.003';
 
 use Moose;
 use Dist::Zilla;
@@ -19,7 +21,6 @@ with 'Dist::Zilla::Role::PluginBundle::Easy';
 # For auto plugins
 AUTOPLUG: {
     use Dist::Zilla::Plugin::AutoPrereqs;
-    use Dist::Zilla::Plugin::Covenant;
     use Dist::Zilla::Plugin::ContributorCovenant;
     use Dist::Zilla::Plugin::ExecDir;
     use Dist::Zilla::Plugin::ExtraTests;
@@ -45,6 +46,7 @@ AUTOPLUG: {
     use Dist::Zilla::Plugin::Test::Kwalitee::Extra;
     use Dist::Zilla::Plugin::Test::NoTabs;
     use Dist::Zilla::Plugin::Test::ReportPrereqs;
+    use Dist::Zilla::Plugin::Test::TrailingSpace;
     use Dist::Zilla::Plugin::Test::UnusedVars;
     use Dist::Zilla::Plugin::Test::UseAllModules;
     use Dist::Zilla::Plugin::Test::Version;
@@ -63,11 +65,12 @@ sub configure {
 
     $self->add_plugins($self->_contributing_plugin());
     $self->add_plugins($self->_copy_files_from_build());
+    $self->add_plugins($self->_covenant());
     $self->add_plugins($self->_mailmap_plugin());
+    $self->add_plugins($self->_todo_plugin());
     $self->add_plugins($self->_travis_plugin());
 
     $self->add_plugins('AutoPrereqs');
-    $self->add_plugins('Covenant');
     $self->add_plugins('ContributorCovenant');
     $self->add_plugins('ExecDir');
     $self->add_plugins('ExtraTests');
@@ -139,6 +142,20 @@ sub _contributing_plugin {
     ];
 }
 
+sub _covenant_plugin {
+    my $self = shift;
+
+    if ( -f 'AUTHOR_PLEDGE' ) { return; }
+
+    return [
+        'GenerateFile::FromShareDir' => 'Generate AUTHOR_PLEDGE' => {
+            -dist     => ( __PACKAGE__ =~ s/::/-/gr ),
+            -filename => 'AUTHOR_PLEDGE',
+            -location => 'root',
+        },
+    ];
+}
+
 sub _mailmap_plugin {
     my $self = shift;
 
@@ -169,6 +186,21 @@ sub _travis_plugin {
     ];
 }
 
+sub _todo_plugin {
+    my $self = shift;
+
+    if ( -f 'TODO' ) { return; }
+
+    return [
+        'GenerateFile::FromShareDir' => 'Generate TODO' => {
+            -dist     => ( __PACKAGE__ =~ s/::/-/gr ),
+            -filename => 'TODO',
+            -source_filename => 'TODO',
+            -location => 'root',
+        },
+    ];
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -185,7 +217,7 @@ Dist::Zilla::PluginBundle::Author::JMASLAK - JMASLAK's Plugin Bundle
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
@@ -193,7 +225,7 @@ This is Joelle Maslak's plugin bundle, used for her modules.  If you're not
 her, you probably want to create your own plugin module because I may modify
 this module based on her needs, breaking third party modules that use this.
 
-All of the following are in this module as of v0.002.
+All of the following are in this module as of v0.003.
 
 It is somewhat equivilent to:
 
@@ -204,7 +236,6 @@ It is somewhat equivilent to:
     [CopyFilesFromBuild]
     copy = 'README.pod'
 
-    [Covenant]
     [ExecDir]
     [ExtraTests]
     [GatherDir]
@@ -245,8 +276,10 @@ It is somewhat equivilent to:
     [UploadToCPAN]
 
 This creates a C<CODE_OF_CONDUCT.md> from the awesome Contributor Covenant
-project, and creates a C<.travis.yml> file that will probably need to be
-edited.  If these files exist already, they will not get overwritten.
+project, a C<TODO> file, an C<AUTHOR_PLEDGE> file that indicates CPAN admins
+can take ownership should the project become abandoned, and a C<.travis.yml>
+file that will probably need to be edited.  If these files exist already,
+they will not get overwritten.
 
 It also generates a C<.mailmap> base file suitable for Joelle, if one does
 not already exists.
@@ -257,7 +290,7 @@ In your C<dist.ini> -
 
     [@Filter]
     -bundle  = @Author::JMASLAK
-    -version = 0.002
+    -version = 0.003
 
 The C<-version> option should specify the latest version required and tested
 with a given package.
